iPhone 研究室 | Apple製品を攻略
Description: iPhone / iPad / Mac といったApple製品を使いこなす方法、新型・新製品の噂、お薦めのアプリを研究するサイト。Androidの話題も少々。アプリ以外の記事を「新着記事」、アプリの情報を「新着アプリ」に
Keywords: iphone

#

## Apple製品を攻略

フォローして更新をチェック

2008/5/7（8年前） 2015/11/27

iPhone / iPad / Mac といったApple製品を使いこなす方法、新型・新製品の噂、お薦めのアプリを研究するサイト。Androidの話題も少々。

アプリ以外の記事を「新着記事」、アプリの情報を「新着アプリ」に分けました。メニューをご活用ください。

## 新着記事リスト

## 【Sale】iPhoneアプリ「Go home」が5日間限定で半額セール！！

2015/12/4 セール・キャンペーン・イベント, デベロッパー投稿

2015年11月にAppStore有料総合71位、仕事効率化カテゴリ2位を獲得したiPhoneアプリ「Go home」 ...

記事を読む

## 記事の下書きはEvernoteでするべき理由

2015/11/27 Wordpress・ブログ運営, 使いこなし術

ブログ記事を書く時は何を使っていますか？Wordpressで直接書き始める人、テキストエディタで下書きする人、投稿用アプリを使う人…...

記事を読む

## シンプルだけど効果的な仕事管理 – リマインダー活用法

2015/11/26 使いこなし術

iPhoneの標準搭載アプリの一つ、リマインダーを活用すると仕事を効率よく進められます。と言ってもそんなに複雑だったり面倒なことをす...

記事を読む

【新着記事へ】

### 【新着順アプリ】

### 【おすすめアプリ】

### 【新着順アクセサリ】

### 【おすすめアクセサリ】

## iPhoneを使いこなすアイデア・Tips

フリックで高速に入力するコツ・モッサリや不安定の解消方法・バッテリー問題の解決など、iPhoneを使いこなすための独自のアイデアやトラブル解決方法が満載。
iPhoneを使いこなす方法を読む

## 信憑性が高い新型iPhoneの噂

正式発表前のApple製品は様々なうわさが飛び交います。iPhone / iPad を中心に、ある程度信憑性がありそうだと判断した噂を選んで掲載しています。
新型iPhoneとiOSに関する噂
iPad Air に関する噂
iPad Pro に関する噂

## 特集記事

通常の記事より読み応えありのまとめ系。iPhoneやiPadを使う上で、役に立つ濃いめの情報です。パスワード管理に関する記事は、大切なiPhoneと個人情報を守るためにぜひ読んでいただきたい。追加ハード不要でiPhoneだけでOKな高音質化・音質改善アプリや、コスパ最強の低価格帯イヤホンの特集も人気です。
特集記事リスト

## 小ネタ・雑談

管理人が興味をもった話題やジョークを、自由に書いたもの。なぜか情報系の記事よりも多く読まれる傾向があるという…
小ネタ・雑談の記事リスト

## Wordpress・ブログ運営

iPhoneと直接は関係ないのですが、Wordpressを高速化するための当サイトの設定や、スマートフォン向けモバイル表示でもぺージキャッシュを効かせる設定はとても良く読まれ、かつ引用もされています。
Wordpress・ブログ運営の記事リスト

## 連絡先など

### 募集情報・コンタクト

アプリの宣伝、記事投稿デベロッパー、寄稿、俺の必殺技、タレコミ情報の募集と管理人へのメールフォーム。

### Appleにフィードバックを送る

iPhone に関する要望を直接 Apple へ伝えるための窓口はここ。

### iPhone 研究室について

管理人の自己紹介とかサイトの歴史などを少々。

シェアしてみんなに知らせよう

フォローして更新をチェック